/*
	alt-tasks : utility for observing ALT Linux tasks
	Copyright (C) 2020 Alexey Appolonov

	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

package ar

//-----------------------------------------------------------------------------
// Write a given subtask that is a part of a task with a given task id and that
// has a given subtask id and that been created for a package with a given name

func (a *Archive) Write(src_name string, task_id TaskId, subtask_id SubTaskId,
		subtask SubTask) {

	src_id, ok := a.package_ids[src_name]
	if !ok {
		a.counter++
		src_id = SrcId(a.counter)
		a.package_ids[src_name] = src_id
		a.packages[src_id] = src_name
		}
	subtask.Src.ID = src_id
	if a.tasks[task_id] == nil {
		a.tasks[task_id] = make(Task)
		}
	a.tasks[task_id][subtask_id] = subtask

	// Updating the time overview
	if a.time_overview[subtask.TS] == nil {
		a.time_overview[subtask.TS] = make(map[TaskId]bool)
		}
	a.time_overview[subtask.TS][task_id] = true

	// Updating the src overview
	if a.src_overview[src_id] == nil {
		a.src_overview[src_id] = make(map[TaskId]bool)
		}
	a.src_overview[src_id][task_id] = true
	}
